@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004 Jimmy Do <crispyleaves@gmail.com>
+ * Copyright (C) 2004-2006 Jimmy Do <crispyleaves@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +21,11 @@
 
 #include "timer-applet.h"
 
+G_BEGIN_DECLS
+
 void
 about_dialog_show (GtkWidget **about_dialog_ptr);
 
+G_END_DECLS
+
 #endif /* ABOUT_DIALOG_H */
