@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004 Jimmy Do <crispyleaves@gmail.com>
+ * Copyright (C) 2004-2006 Jimmy Do <crispyleaves@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -81,30 +81,6 @@ on_sound_file_chooser_dialog_response (GtkDialog *dialog, gint response, PanelAp
 	}
 }
 
-static void
-on_always_on_top_changed (GtkWidget *check_button, PanelApplet *applet)
-{
-	gboolean value;
-
-	g_assert (applet);
-	
-	g_object_get (GTK_CHECK_BUTTON (check_button), "active", &value, NULL);
-	
-	panel_applet_gconf_set_bool (applet, NOTIFICATION_DIALOG_ALWAYS_ON_TOP_KEY, value, NULL);
-}
-
-static void
-on_sticky_dialog_changed (GtkWidget *check_button, PanelApplet *applet)
-{
-	gboolean value;
-
-	g_assert (applet);
-	
-	g_object_get (GTK_CHECK_BUTTON (check_button), "active", &value, NULL);
-	
-	panel_applet_gconf_set_bool (applet, NOTIFICATION_DIALOG_STICKY_KEY, value, NULL);
-}
-
 static void
 on_prefs_dialog_response (GtkDialog *dialog, gint response, gpointer user_data)
 {
@@ -136,8 +112,6 @@ prefs_dialog_new (PanelApplet *applet)
 	GtkWidget *radio_use_custom_sound;
 	GtkWidget *file_chooser_dialog;
 	GtkWidget *sound_file_chooser;
-	GtkWidget *check_always_on_top;
-	GtkWidget *check_sticky_dialog;
 	
 	prefs_dialog = gtk_dialog_new_with_buttons (_("Timer Preferences"), NULL, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
 	
@@ -188,16 +162,6 @@ prefs_dialog_new (PanelApplet *applet)
 	g_object_set_data (G_OBJECT (prefs_dialog), "prefs-use-custom-sound", radio_use_custom_sound);
 	g_object_set_data (G_OBJECT (prefs_dialog), "prefs-sound-file-chooser", sound_file_chooser);
 	
-	check_always_on_top = gtk_check_button_new_with_mnemonic (_("_Keep notification dialog on top of all other windows"));
-	gtk_box_pack_start (GTK_BOX (main_vbox), check_always_on_top, FALSE, FALSE, 0);
-	g_signal_connect (G_OBJECT (check_always_on_top), "toggled", G_CALLBACK (on_always_on_top_changed), applet);
-	g_object_set_data (G_OBJECT (prefs_dialog), "prefs-notification-dialog-always-on-top", check_always_on_top);
-	
-	check_sticky_dialog = gtk_check_button_new_with_mnemonic (_("_Display notification dialog on all workspaces"));
-	gtk_box_pack_start (GTK_BOX (main_vbox), check_sticky_dialog, FALSE, FALSE, 0);
-	g_signal_connect (G_OBJECT (check_sticky_dialog), "toggled", G_CALLBACK (on_sticky_dialog_changed), applet);
-	g_object_set_data (G_OBJECT (prefs_dialog), "prefs-notification-dialog-sticky", check_sticky_dialog);
-	
 	prefs_dialog_update (GTK_DIALOG (prefs_dialog));
 	
 	
@@ -212,8 +176,6 @@ prefs_dialog_new (PanelApplet *applet)
 	gtk_widget_show (sound_file_chooser);
 	gtk_widget_show (custom_sound_group);
 	gtk_widget_show (play_sound_group);
-	gtk_widget_show (check_always_on_top);
-	gtk_widget_show (check_sticky_dialog);
 
 	return prefs_dialog;
 }
@@ -233,8 +195,6 @@ prefs_dialog_update (GtkDialog *prefs_dialog)
 	gboolean play_sound;
 	gboolean use_custom_sound;
 	gchar *custom_sound_path;
-	gboolean always_on_top;
-	gboolean sticky_dialog;
 	PanelApplet *applet;
 	
 	applet = g_object_get_data (G_OBJECT (prefs_dialog), "panel-applet");
@@ -244,8 +204,6 @@ prefs_dialog_update (GtkDialog *prefs_dialog)
 	play_sound = panel_applet_gconf_get_bool (applet, PLAY_NOTIFICATION_SOUND_KEY, NULL);
 	use_custom_sound = panel_applet_gconf_get_bool (applet, USE_CUST_NOTIFICATION_SOUND_KEY, NULL);
 	custom_sound_path = panel_applet_gconf_get_string (applet, CUST_NOTIFICATION_SOUND_PATH_KEY, NULL);
-	always_on_top = panel_applet_gconf_get_bool (applet, NOTIFICATION_DIALOG_ALWAYS_ON_TOP_KEY, NULL);
-	sticky_dialog = panel_applet_gconf_get_bool (applet, NOTIFICATION_DIALOG_STICKY_KEY, NULL);
 
 	if (custom_sound_path == NULL) {
 		custom_sound_path = g_strdup ("");
@@ -257,23 +215,18 @@ prefs_dialog_update (GtkDialog *prefs_dialog)
 		GtkWidget *prefs_use_default_sound;
 		GtkWidget *prefs_use_custom_sound;
 		GtkWidget *prefs_sound_file_chooser;
-		GtkWidget *prefs_notification_dialog_always_on_top;
-		GtkWidget *prefs_notification_dialog_sticky;
 
 		prefs_show_remaining_time = g_object_get_data (G_OBJECT (prefs_dialog), "prefs-show-remaining-time");
 		prefs_play_notification_sound = g_object_get_data (G_OBJECT (prefs_dialog), "prefs-play-notification-sound");
 		prefs_use_default_sound = g_object_get_data (G_OBJECT (prefs_dialog), "prefs-use-default-sound");
 		prefs_use_custom_sound = g_object_get_data (G_OBJECT (prefs_dialog), "prefs-use-custom-sound");
 		prefs_sound_file_chooser = g_object_get_data (G_OBJECT (prefs_dialog), "prefs-sound-file-chooser");
-		prefs_notification_dialog_always_on_top = g_object_get_data (G_OBJECT (prefs_dialog), "prefs-notification-dialog-always-on-top");
-		prefs_notification_dialog_sticky = g_object_get_data (G_OBJECT (prefs_dialog), "prefs-notification-dialog-sticky");
+
 		g_assert (prefs_show_remaining_time);
 		g_assert (prefs_play_notification_sound);
 		g_assert (prefs_use_default_sound);
 		g_assert (prefs_use_custom_sound);
 		g_assert (prefs_sound_file_chooser);
-		g_assert (prefs_notification_dialog_always_on_top);
-		g_assert (prefs_notification_dialog_sticky);
 
 		g_object_set (G_OBJECT (prefs_show_remaining_time), "active", show_time, NULL);
 		g_object_set (G_OBJECT (prefs_play_notification_sound), "active", play_sound, NULL);
@@ -289,8 +242,5 @@ prefs_dialog_update (GtkDialog *prefs_dialog)
 		gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (prefs_sound_file_chooser), custom_sound_path);
 		g_free (custom_sound_path);
 		custom_sound_path = NULL;
-
-		g_object_set (G_OBJECT (prefs_notification_dialog_always_on_top), "active", always_on_top, NULL);
-		g_object_set (G_OBJECT (prefs_notification_dialog_sticky), "active", sticky_dialog, NULL);
 	}
 }
