@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004 Jimmy Do <crispyleaves@gmail.com>
+ * Copyright (C) 2004-2006 Jimmy Do <crispyleaves@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,8 @@
 #include <gtk/gtk.h>
 #include <panel-applet.h>
 
+G_BEGIN_DECLS
+
 GtkWidget *
 prefs_dialog_new (PanelApplet *applet);
 void
@@ -28,4 +30,6 @@ prefs_dialog_open (GtkDialog *prefs_dialog);
 void
 prefs_dialog_update (GtkDialog *prefs_dialog);
 
+G_END_DECLS
+
 #endif /* PREFS_DIALOG_H */
