@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004 Jimmy Do <crispyleaves@gmail.com>
+ * Copyright (C) 2004-2006 Jimmy Do <crispyleaves@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,22 +20,22 @@
 #include <config.h>
 #endif
 
+#include "start-timer-dialog.h"
+
 #include <string.h>
 #include <panel-applet-gconf.h>
-
-#include "start-timer-dialog.h"
-#include "profile-manager.h"
-#include "add-profile-dialog.h"
+#include "add-preset-dialog.h"
 #include "layout-utils.h"
+#include "presets-manager.h"
 
 typedef struct
 {
-	gdouble duration;
+	guint duration;
 	gchar *name;
 } StartTimerStoredInfo;
 
 static void
-dialog_set_duration (GtkWidget *start_timer_dialog, gdouble duration)
+dialog_set_duration (GtkWidget *start_timer_dialog, guint duration)
 {
 	GtkWidget *spin_hours, *spin_minutes, *spin_seconds;
 	guint num_hours, num_minutes, num_seconds;
@@ -84,28 +84,34 @@ load_selected_preset (TimerApplet *timer_applet)
 	/* Update hours, minutes, and seconds spin buttons,
 	 * and update name entry.
 	 */
-	GtkTreeRowReference *selected_profile;
+	GtkTreeRowReference *selected_preset;
 	gchar *name;
-	gdouble duration;
+	guint duration;
 	
 	g_assert (timer_applet);
 	g_assert (timer_applet->start_timer_dialog);
-	g_assert (timer_applet->start_timer_profile_manager_widget);
-	selected_profile = profile_manager_get_selected_profile (timer_applet->start_timer_profile_manager_widget);
+	g_assert (timer_applet->start_timer_presets_manager_widget);
+	selected_preset = presets_manager_get_selected_preset (timer_applet->start_timer_presets_manager_widget);
 	
-	g_assert (selected_profile);
+	g_assert (selected_preset);
 	
-	timer_applet_get_profile_name_and_duration (timer_applet, selected_profile, &name, &duration);
+	gloo_presets_get_name_and_duration (timer_applet->gloo_presets,
+										selected_preset,
+										&name,
+										&duration);
 	
 	dialog_set_duration (timer_applet->start_timer_dialog, duration);
 	dialog_set_name (timer_applet->start_timer_dialog, name);
+
+	g_free (name);
+	name = NULL;
 }
 
 static void
 handle_ok_clicked (TimerApplet *timer_applet)
 {
 	gchar *preset_name;
-	gdouble timer_duration;
+	guint timer_duration;
 
 	g_assert (timer_applet);
 	g_assert (timer_applet->start_timer_dialog);
@@ -156,7 +162,7 @@ handle_ok_clicked (TimerApplet *timer_applet)
 		 * even if the user opens the dialog, enters new values, and then presses Cancel. */
 		{
 			panel_applet_gconf_set_string (timer_applet->applet, "last_used_name", preset_name, NULL);
-			panel_applet_gconf_set_float (timer_applet->applet, "last_used_duration", timer_duration, NULL);
+			panel_applet_gconf_set_int (timer_applet->applet, "last_used_duration", timer_duration, NULL);
 		}
 	}
 
@@ -196,42 +202,66 @@ on_load_preset_clicked (GtkWidget *button, TimerApplet *timer_applet)
 }
 
 static void
-on_selection_empty (GtkWidget *profile_manager)
+on_selection_empty (GtkWidget *presets_manager)
 {
  	GtkWidget *load_preset_button;
- 	load_preset_button = g_object_get_data (G_OBJECT (profile_manager), "load-preset-button");
+ 	load_preset_button = g_object_get_data (G_OBJECT (presets_manager), "load-preset-button");
  	g_object_set (G_OBJECT (load_preset_button), "sensitive", FALSE, NULL);
 }
 
 static void
-on_selection_not_empty (GtkWidget *profile_manager)
+on_selection_not_empty (GtkWidget *presets_manager)
 {
  	GtkWidget *load_preset_button;
- 	load_preset_button = g_object_get_data (G_OBJECT (profile_manager), "load-preset-button");
+ 	load_preset_button = g_object_get_data (G_OBJECT (presets_manager), "load-preset-button");
  	g_object_set (G_OBJECT (load_preset_button), "sensitive", TRUE, NULL);
 }
 
 static void
-on_profile_added (GtkWidget *profile_manager, gchar *profile_name, gdouble profile_duration, gpointer user_data)
+on_preset_added (GtkWidget *presets_manager, gchar *preset_name, guint preset_duration, gpointer user_data)
 {
+	TimerApplet *timer_applet;
 	GtkTreeRowReference *new_row_ref;
-	new_row_ref = timer_applet_add_preset (profile_name, profile_duration);
-	profile_manager_select_row (profile_manager, new_row_ref);
+
+	timer_applet = (TimerApplet *)user_data;
+
+	g_assert (timer_applet != NULL);
+
+	new_row_ref = gloo_presets_add_preset (timer_applet->gloo_presets,
+										   preset_name,
+										   (guint)preset_duration);
+	presets_manager_select_row (presets_manager, new_row_ref);
 }
 
 static void
-on_profile_edited (GtkWidget *profile_manager, GtkTreeRowReference *row_ref, gchar *profile_name, gdouble profile_duration, gpointer user_data)
+on_preset_edited (GtkWidget *presets_manager, GtkTreeRowReference *row_ref, gchar *preset_name, guint preset_duration, gpointer user_data)
 {
-	timer_applet_update_preset (row_ref, profile_name, profile_duration);
+	TimerApplet *timer_applet;
+	
+	timer_applet = (TimerApplet *)user_data;
+
+	g_assert (timer_applet != NULL);
+
+	gloo_presets_update_preset (timer_applet->gloo_presets,
+								row_ref,
+								preset_name,
+								preset_duration);
 	
 	/* Cause update of spin buttons */
-	profile_manager_select_row (profile_manager, row_ref);
+	presets_manager_select_row (presets_manager, row_ref);
 }
 
 static void
-on_profile_deleted (GtkWidget *profile_manager, GtkTreeRowReference *row_ref, gpointer user_data)
+on_preset_deleted (GtkWidget *presets_manager, GtkTreeRowReference *row_ref, gpointer user_data)
 {
-	timer_applet_remove_preset (row_ref);
+	TimerApplet *timer_applet;
+
+	timer_applet = (TimerApplet *)user_data;
+	
+	g_assert (timer_applet != NULL);
+
+	gloo_presets_remove_preset (timer_applet->gloo_presets,
+								row_ref);
 }
 
 static void
@@ -330,7 +360,7 @@ start_timer_dialog_create (TimerApplet *timer_applet)
 	{
 		GtkWidget *presets_label;
 		GtkWidget *presets_group;
-		GtkWidget *profile_manager_widget;
+		GtkWidget *presets_manager_widget;
 		GtkWidget *load_preset_button;
 			
 		presets_label = gtk_label_new (_("<span weight=\"bold\">Presets</span>"));
@@ -346,27 +376,29 @@ start_timer_dialog_create (TimerApplet *timer_applet)
 		g_signal_connect (G_OBJECT (load_preset_button), "clicked", G_CALLBACK (on_load_preset_clicked), timer_applet);
 		
 		presets_group = create_group_box (presets_label);
-		profile_manager_widget = profile_manager_new (GTK_TREE_MODEL (timer_applet_get_presets_list ()));
-		timer_applet->start_timer_profile_manager_widget = profile_manager_widget;
+		presets_manager_widget = presets_manager_new (GTK_TREE_MODEL (timer_applet->gloo_presets));
+		timer_applet->start_timer_presets_manager_widget = presets_manager_widget;
 		
-		profile_manager_set_profile_handlers (profile_manager_widget, on_profile_added, NULL,
-										on_profile_edited, NULL, on_profile_deleted, NULL);
-		g_object_set_data (G_OBJECT (profile_manager_widget), "ok-button", ok_button);
-		g_object_set_data (G_OBJECT (profile_manager_widget), "load-preset-button", load_preset_button);
-		profile_manager_set_selection_change_handlers (profile_manager_widget, on_selection_empty, on_selection_not_empty);
+		presets_manager_set_preset_handlers (presets_manager_widget,
+											 on_preset_added, timer_applet,
+											 on_preset_edited, timer_applet,
+											 on_preset_deleted, timer_applet);
+		g_object_set_data (G_OBJECT (presets_manager_widget), "ok-button", ok_button);
+		g_object_set_data (G_OBJECT (presets_manager_widget), "load-preset-button", load_preset_button);
+		presets_manager_set_selection_change_handlers (presets_manager_widget, on_selection_empty, on_selection_not_empty);
 		{
-			GtkWidget *profile_manager_tree_view;
-			profile_manager_tree_view = profile_manager_get_tree_view (profile_manager_widget);
-			g_signal_connect (G_OBJECT (profile_manager_tree_view), "row-activated", G_CALLBACK (on_preset_activated), timer_applet);
+			GtkWidget *presets_manager_tree_view;
+			presets_manager_tree_view = presets_manager_get_tree_view (presets_manager_widget);
+			g_signal_connect (G_OBJECT (presets_manager_tree_view), "row-activated", G_CALLBACK (on_preset_activated), timer_applet);
 		}
 		
-		g_assert (timer_applet->start_timer_profile_manager_widget);
+		g_assert (timer_applet->start_timer_presets_manager_widget);
 		
-		group_box_add_row_full (presets_group, profile_manager_widget, TRUE, TRUE);
+		group_box_add_row_full (presets_group, presets_manager_widget, TRUE, TRUE);
 		group_box_add_row (presets_group, load_preset_button);
 		gtk_box_pack_start (GTK_BOX (main_vbox), presets_group, TRUE, TRUE, 0);
 		gtk_widget_show (presets_label);
-		gtk_widget_show (profile_manager_widget);
+		gtk_widget_show (presets_manager_widget);
 		gtk_widget_show (load_preset_button);
 		gtk_widget_show (presets_group);
 	}
@@ -381,10 +413,10 @@ void
 start_timer_dialog_open (TimerApplet *timer_applet)
 {
 	gchar *timer_name;
-	gdouble timer_duration;
+	guint timer_duration;
 
 	timer_name = panel_applet_gconf_get_string (timer_applet->applet, "last_used_name", NULL);
-	timer_duration = panel_applet_gconf_get_float (timer_applet->applet, "last_used_duration", NULL);
+	timer_duration = panel_applet_gconf_get_int (timer_applet->applet, "last_used_duration", NULL);
 
 	/* Schema should ensure that timer_name is not NULL, but we'll be nice and handle NULL anyway. */
 	if (timer_name == NULL) {
@@ -398,7 +430,7 @@ start_timer_dialog_open (TimerApplet *timer_applet)
 }
 	
 void
-start_timer_dialog_open_with_name_and_duration (TimerApplet *timer_applet, const gchar *timer_name, gdouble timer_duration)
+start_timer_dialog_open_with_name_and_duration (TimerApplet *timer_applet, const gchar *timer_name, guint timer_duration)
 {
 	g_assert (timer_applet != NULL);
 	g_assert (timer_name != NULL);
