@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004 Jimmy Do <crispyleaves@gmail.com>
+ * Copyright (C) 2004-2006 Jimmy Do <crispyleaves@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,10 +21,15 @@
 #include <gtk/gtk.h>
 #include "timer-applet.h"
 
+G_BEGIN_DECLS
+
 void
 start_timer_dialog_create (TimerApplet *timer_applet);
 void
 start_timer_dialog_open (TimerApplet *timer_applet);
 void
-start_timer_dialog_open_with_name_and_duration (TimerApplet *timer_applet, const gchar *timer_name, gdouble timer_duration);
+start_timer_dialog_open_with_name_and_duration (TimerApplet *timer_applet, const gchar *timer_name, guint timer_duration);
+
+G_END_DECLS
+
 #endif /* START_TIMER_DIALOG_H */
